/*
 * Javascript Library for the XooNIps IndexTree
 */

if ( typeof( XooNIpsTreeJS ) == 'undefined' ) XooNIpsTreeJS = function() {};

/**
 * The cookie controller class
 * @package XooNIpsTreeJS
 */

/** 
 * constructor
 *
 * @access public
 * @param string domain cookie domain
 * @param string path cookie path
 * @param number expires how many days the cookie expiry
 *               0 : this session only
 *        positive : n days
 *        negative : never
 * @param boolean secure set cookie when secure
 * @return object instance
 */
XooNIpsTreeJS.Cookie = function( domain, path, expires, secure ) {
  // check cookie enabled
  this.cookie_enabled = ( navigator.cookieEnabled ) ? true : false;
  if ( typeof( navigator.cookieEnabled ) == 'undefined' && ! this.cookie_enabled ) {
    // if not ie4+ nor ns6+
    document.cookie = 'testcookie';
    this.cookie_enabled = ( document.cookie.indexOf( 'testcookie' ) != -1 ) ? true : false;
  }
  this.expires_clear = 'Fri, 31-Dec-1999 23:59:59 GMT';
  this.expires_never = 'Tue, 1-Jan-2030 00:00:00 GMT';
  this.cookie_domain = domain;
  this.cookie_path = path;
  this.cookie_expires = expires;
  this.cookie_secure = secure;
  return this;
}

XooNIpsTreeJS.Cookie.prototype = {
  /**
   * set value to cookie
   *
   * @access public
   * @param string key cookie key
   * @param string val cookie value
   * @return boolean false if failure
   */
  setCookie: function( key, val ) {
    if ( ! this.cookie_enabled ) {
      return false;
    }
    var cookie = key + '=' + escape( val ) + ';';
    if ( this.cookie_domain ) {
      cookie += ' domain=' + this.cookie_domain + ';';
    }
    if ( this.cookie_path ) {
      cookie += ' path=' + this.cookie_path + ';';
    }
    if ( this.cookie_expires > 0 ) {
      var today = new Date();
      var expire = new Date();
      expire.setTime( today.getTime() + 3600000 * 24 * this.cookie_expires );
      cookie += ' expires=' + expire.toGMTString() + ';';
    } else if ( this.cookie_expires < 0 ) {
      cookie += ' expires=' + this.expires_never + ';';
    }
    if ( this.cookie_secure ) {
      cookie += ' secure;';
    }
    document.cookie = cookie;
    return true;
  },
  
  /**
   * get value from cookie 
   *
   * @access public
   * @param string key cookie key
   * @return string value
   */
  getCookie: function( key ) {
    if ( ! this.cookie_enabled ) {
      return '';
    }
    var cookie = document.cookie + ';';
    var pos = cookie.indexOf( key, 0 );
    if ( pos == -1 ) {
      return ''; // not found
    }
    cookie = cookie.substring( pos, cookie.length );
    var s_pos = cookie.indexOf( '=', 0 );
    var e_pos = cookie.indexOf( ';', s_pos );
    return unescape( cookie.substring( s_pos + 1, e_pos ) );
  },

  /**
   * delete variable from cookie
   *
   * @access public
   * @param string key cookie key
   * @return boolean false if failure
   */
  deleteCookie: function( key ) {
    if ( ! this.cookie_enabled ) {
      return false;
    }
    var cookie = key + '=;';
    if ( this.cookie_domain ) {
      cookie += ' domain=' + this.cookie_domain + ';';
    }
    if ( this.cookie_path ) {
      cookie += ' path=' + this.cookie_path + ';';
    }
    cookie += ' expires=' + this.expires_clear + ';';
    if ( this.cookie_secure ) {
      cookie += ' secure;';
    }
    document.cookie = cookie;
    return true;
  }
}


/**
 * The Scroll Bar Position controller class
 * @package XooNIpsTreeJS
 */

/** 
 * constructor
 *
 * @access public
 * @param string cookie name
 * @param object XooNIpsTreeJS.Cookie instance
 * @return object instance
 */
XooNIpsTreeJS.ScrollPosition = function( cookie, cookie_key ) {
  this.positions = {};
  this.cookie = cookie;
  this.cookie_key = cookie_key;
  return this;
}

XooNIpsTreeJS.ScrollPosition.prototype = {
  /**
   * save scroll position to cookie
   *
   * @access public
   * @param string prefix
   */
  saveScrollPosition: function( prefix ) {
    var x_name = 'x' + prefix;
    var y_name = 'y' + prefix;
    if ( window.pageXOffset || window.pageYOffset ){
      this.positions[x_name] = window.pageXOffset;
      this.positions[y_name] = window.pageYOffset;
    } else if ( document.documentElement && ( document.documentElement.scrollLeft || document.documentElement.scrollTop ) ) {
      this.positions[x_name] = document.documentElement.scrollLeft;
      this.positions[y_name] = document.documentElement.scrollTop;
    } else if ( document.body ) {
      this.positions[x_name] = document.body.scrollLeft;
      this.positions[y_name] = document.body.scrollTop;
    } else {
      return; // no support to get scroll positions
    }

    // save position to cookie
    var ar = new Array();
    for ( var key in this.positions ) {
      ar.push( key + "/" + this.positions[key] );
    }
    this.cookie.setCookie( this.cookie_key, ar.join( ',' ) );
  },

  /**
   * load scroll positions from cookie
   *
   * @access public
   * @param string prefix
   */
  loadScrollPosition: function( prefix ) {
    var x_name = 'x' + prefix;
    var y_name = 'y' + prefix;
    var str = this.cookie.getCookie( this.cookie_key );
    if ( str ) {
      // found
      var ar = str.split(',');
      for ( var i = 0; i < ar.length; i++ ) {
        var keyval = ar[i].split('/');
        this.positions[keyval[0]] = keyval[1];
      }
      var x = Number( this.positions[x_name] );
      var y = Number( this.positions[y_name] );
      if ( isNaN( x ) || x < 0 ) { x = 0; }
      if ( isNaN( y ) || y < 0 ) { y = 0; }
      // window.scrollTo( x, y ); // IE fails ( only if y>height/2 ?? )
      setTimeout( 'window.scrollTo(' + x + ', ' + y + ')', 1 );
    }
  }
}


/**
 * The Tree Tab control class
 * @package XooNIpsTreeJS
 */

/** 
 * constructor
 *
 * @access public
 * @return object instance
 */
XooNIpsTreeJS.TabControl = function( cookie, cookie_key_tab, cookie_key_scroll ) {
  this.hash = {};
  this.tabs = {};
  this.count = 0;
  this.selected = null;
  this.cookie = cookie;
  this.cookie_key = cookie_key_tab;
  this.scroll_position = new XooNIpsTreeJS.ScrollPosition( cookie, cookie_key_scroll );
  return this;
}

XooNIpsTreeJS.TabControl.prototype = {
  /**
   * register page id
   *
   * @access public
   * @param string id element id
   * @param number n element number
   */
  registerTab: function( id, n ) {
    this.hash[n] = id;
    this.tabs[this.count] = n;
    this.count++;
  },

  /**
   * set current tab
   *
   * @access public
   * @param number n element number
   */
  selectTab: function( n ) {
    if ( this.count == 0 || this.selected == n ) {
      return;
    }
    if ( this.selected != null ) {
      this.scroll_position.saveScrollPosition( this.selected );
    }
    for ( var i = 0; i < this.count; i++ ) {
       var page = this.tabs[i];
       var id = this.hash[page];
       var elem = document.getElementById( id );
       elem.style.display = ( page == n ) ? 'block' : 'none';
    }
    this.scroll_position.loadScrollPosition( n );
    this.selected = n;
  },

  /**
   * save selected tab
   *
   * @access public
   */
  saveSelectedTab: function() {
    if ( this.count == 0 || this.selected == null ) {
      return;
    }
    this.cookie.setCookie( this.cookie_key, this.selected );
    this.scroll_position.saveScrollPosition( this.selected );
  }
}
